# pylint: disable=line-too-long
from enum import StrEnum


class MessageType(StrEnum):
    BALANCE_RESPONSIBLE_SCHEDULE                                        = "A01"  #: A schedule which has been prepared by a balance responsible party providing planned schedule information.
    ALLOCATED_CAPACITY_SCHEDULE                                         = "A02"  #: A schedule which has been prepared by a capacity allocator providing allocated capacity.
    BALANCE_AREA_SCHEDULE                                               = "A03"  #: A schedule that provides the planned schedule information for a balance area.
    SYSTEM_OPERATOR_AREA_SCHEDULE                                       = "A04"  #: A compilation of all external schedules concerning two System Operator areas of all balance responsible parties.
    CONTROL_BLOCK_AREA_SCHEDULE                                         = "A05"  #: A compilation of all the exchange programs of all control areas for one control block with all neighbouring control areas of a neighbouring control block.
    COORDINATION_CENTER_AREA_SCHEDULE                                   = "A06"  #: A compilation of the exchange programs of all exchange blocks divided into UCTE south and north.
    INTERMEDIATE_CONFIRMATION_REPORT                                    = "A07"  #: An intermediate confirmation report that may be produced between final cutoffs.
    FINAL_CONFIRMATION_REPORT                                           = "A08"  #: A final confirmation report that is produced after a final cutoff.
    FINALISED_SCHEDULE                                                  = "A09"  #: A compilation of a set of schedules that have been finalized after a given cutoff.
    REGULATION_DATA_REPORT                                              = "A10"  #: A compilation of the time series employed on a given day to ensure the balance of the system.
    AGGREGATED_ENERGY_DATA_REPORT                                       = "A11"  #: A compilation of the time series of all the meter readings or their equivalent for a given period.
    IMBALANCE_REPORT                                                    = "A12"  #: The report containing the complete situation of a given period for a party and including the schedules, regulation data and actual or calculated readings.
    INTERCONNECTION_CAPACITY                                            = "A13"  #: Document for cross-border capacity exchanges.
    RESOURCE_PROVIDER_RESOURCE_SCHEDULE                                 = "A14"  #: A document providing the schedules for resource objects submitted by a resource provider.
    ACQUIRING_SYSTEM_OPERATOR_RESERVE_SCHEDULE                          = "A15"  #: A document providing reserve purchases submitted by an Acquiring System Operator.
    ANOMALY_REPORT                                                      = "A16"  #: A document providing anomaly information for the receiving party to correct.
    ACKNOWLEDGEMENT_DOCUMENT                                            = "A17"  #: A document providing acknowledgement information.
    CONFIRMATION_REPORT                                                 = "A18"  #: A document providing confirmation information.
    CAPACITY_FOR_RESALE                                                 = "A19"  #: A document providing information about capacity for resale.
    APPROVED_CAPACITY_TRANSFER                                          = "A20"  #: A document to approve a capacity transfer.
    CAPACITY_TRANSFER_NOTIFICATION                                      = "A21"  #: A document notifying a capacity transfer.
    TRANSMISSION_RIGHTS_PORTFOLIO                                       = "A22"  #: A document providing the portfolio of the transmission capacity rights of a market participant.
    ALLOCATIONS                                                         = "A23"  #: A document providing the capacity allocations for a border.
    BID_DOCUMENT                                                        = "A24"  #: A document providing bid information.
    ALLOCATION_RESULT_DOCUMENT                                          = "A25"  #: A document providing the allocation results of an auction.
    CAPACITY_DOCUMENT                                                   = "A26"  #: A document providing capacity information.
    RIGHTS_DOCUMENT                                                     = "A27"  #: A document providing transmission capacity rights information.
    GENERATION_AVAILABILITY_SCHEDULE                                    = "A28"  #: This document contains information related to energy availability.
    CROSS_BORDER_SCHEDULE                                               = "A30"  #: This document contains the cross border schedules for all the borders of a given country where energy is exchanged.
    AGREED_CAPACITY                                                     = "A31"  #: The capacity agreed between parties.
    PROPOSED_CAPACITY                                                   = "A32"  #: The capacity proposed for agreement between parties.
    SYSTEM_VERTICAL_LOAD                                                = "A33"  #: The sum of all flows out of the transmission grid via directly connected transformers and lines to distribution grids and end consumers as known by the System Operator.
    ESCALATION_DOCUMENT                                                 = "A34"  #: A document which requesting the escalation of a situation.
    TROUBLE_SHOOTING_DOCUMENT                                           = "A35"  #: A document providing trouble shooting information for the resolution of a problem.
    DEACTIVATION_DOCUMENT                                               = "A36"  #: The capacity proposed for agreement between parties.
    RESERVE_TENDER_DOCUMENT                                             = "A37"  #: The document that is used for the tendering for reserves within the ERRP process.
    RESERVE_ALLOCATION_RESULT_DOCUMENT                                  = "A38"  #: The document used to provide the results of a Reserve auction.
    SATCR_ACTIVATION                                                    = "A39"  #: The document is used to provide the activation of reserves through the SATCR process.
    DATCR_ACTIVATION                                                    = "A40"  #: The document is used to provide the activation of reserves through the DATCR process.
    ACTIVATION_RESPONSE                                                 = "A41"  #: The document is used to provide a response to a request to activate reserves.
    TENDER_REDUCTION                                                    = "A42"  #: The document is used to provide information concerning the reduction of a previously submitted tender.
    MOL_DOCUMENT                                                        = "A43"  #: The document is used to provide Merit Order List information.
    PRICE_DOCUMENT                                                      = "A44"  #: The document is used to provide market spot price information.
    MEASUREMENT_VALUE_DOCUMENT                                          = "A45"  #: The document is used to provide measurement information from measurement devices.
    SOAM_DOCUMENT                                                       = "A46"  #: The document is used to provide system operator accounting data for matching.
    SOVA_DOCUMENT                                                       = "A47"  #: The document is used to provide system operator validated accounting data.
    CCVA_DOCUMENT                                                       = "A48"  #: The document is used to provide coordination center validated accounting data.
    DAILY_SETTLEMENT_DOCUMENT                                           = "A49"  #: The document is used to provide daily settlement information.
    WEEKLY_SETTLEMENT_DOCUMENT                                          = "A50"  #: The document is used to provide weekly settlement information.
    CAPACITY_AUCTION_SPECIFICATION_DOCUMENT                             = "A51"  #: The document is used to provide capacity auction specification information.
    MARKET_COUPLING_RESULTS_DOCUMENT                                    = "A52"  #: The document is used to provide the results of a market coupling auction.
    OUTAGE_PUBLICATION_DOCUMENT                                         = "A53"  #: The document is used to provide the outage information for publication.
    FORCED_GENERATION_OUTAGE_DOCUMENT                                   = "A54"  #: A document providing information on forced generation outages.
    SUMMARISED_MARKET_SCHEDULE                                          = "A55"  #: A compilation of all external schedules concerning two Market Balance Areas of all balance responsible parties.
    COMPENSATION_PROGRAM_SCHEDULE                                       = "A56"  #: A schedule that provides the schedule information for the compensation of unintended deviation.
    LOAD_FREQUENCY_CONTROL_PROGRAM_SCHEDULE                             = "A57"  #: A schedule that provides the schedule information for the Load Frequency Control Program of a Control Area or a Control Block.
    TIMEFRAME_INDEPENDENT_SCHEDULE                                      = "A58"  #: A compilation of all external Timeframe Independent Schedules concerning two System Operators.
    STATUS_REQUEST_FOR_A_STATUS_WITHIN_A_PROCESS                        = "A59"  #: A status request being made concerning the status of information within the context of a specific ongoing process.
    STATUS_REQUEST_FOR_A_POSITION_INDEPENDENTLY_FROM_A_SPECIFIC_PROCESS = "A60"  #: A status request concerning the position of an object independently of any ongoing processes.
    ESTIMATED_NET_TRANSFER_CAPACITY                                     = "A61"  #: The estimated net transfer capacity for a given border.
    COMPENSATION_RIGHTS                                                 = "A62"  #: The capacity rights that have been allocated as compensation.
    REDISPATCH_NOTICE                                                   = "A63"  #: A notice to confirm the actions agreed between System Operators to resolve a congestion situation through redispatch.
    TENDER_REDUCTION_RESPONSE                                           = "A64"  #: A response to a tender reduction request that provides corrections to the initial document.
    SYSTEM_TOTAL_LOAD                                                   = "A65"  #: Total load', including losses without power used for energy storage, is equal to generation deducted with exports, added with imports and deducted with power used for energy storage.
    FINAL_MOL                                                           = "A66"  #: A document providing the information concerning the situation of the MOL at the end of an activation period.
    RESOURCE_PROVIDER_SCHEDULE_FOR_PRODUCTION_CONSUMPTION               = "A67"  #: A document providing the schedules for production/consumption for resource objects submitted by a resource provider.
    INSTALLED_GENERATION_PER_TYPE                                       = "A68"  #: A document providing the installed generation per generation type.
    WIND_AND_SOLAR_FORECAST                                             = "A69"  #: A document providing the forecast of wind and solar generation.
    LOAD_FORECAST_MARGIN                                                = "A70"  #: A document providing the load forecast margin for a period.
    GENERATION_FORECAST                                                 = "A71"  #: A document providing the generation forecast for a period.
    RESERVOIR_FILLING_INFORMATION                                       = "A72"  #: A document providing information concerning the filling of reservoirs.
    ACTUAL_GENERATION                                                   = "A73"  #: A document providing the actual generation for a period.
    WIND_AND_SOLAR_GENERATION                                           = "A74"  #: A document providing the generation of wind and solar energy for a period.
    ACTUAL_GENERATION_PER_TYPE                                          = "A75"  #: A document providing the actual generation per generation type for a period.
    LOAD_UNAVAILABILITY                                                 = "A76"  #: A document providing the unavailability of units providing load on the network.
    PRODUCTION_UNAVAILABILITY                                           = "A77"  #: A document providing the unavailability of production units providing energy to the network.
    TRANSMISSION_UNAVAILABILITY                                         = "A78"  #: A document providing the unavailability of transmission capacity on the network.
    OFFSHORE_GRID_INFRASTRUCTURE_UNAVAILABILITY                         = "A79"  #: A document providing the unavailability of an offshore grid infrastructure to the network.
    GENERATION_UNAVAILABILITY                                           = "A80"  #: A document providing the unavailability of generation units providing energy to the network.
    CONTRACTED_RESERVES                                                 = "A81"  #: A document providing the reserves contracted for a period.
    ACCEPTED_OFFERS                                                     = "A82"  #: A document providing the offers of reserves that have been accepted for a period.
    ACTIVATED_BALANCING_QUANTITIES                                      = "A83"  #: A document providing the quantities of reserves that have been activated for balancing.
    ACTIVATED_BALANCING_PRICES                                          = "A84"  #: A document providing the prices of the reserves that have been activated for balancing.
    IMBALANCE_PRICES                                                    = "A85"  #: A document providing the prices of reserves due to imbalance for a period.
    IMBALANCE_VOLUME                                                    = "A86"  #: A document providing the volume of the imbalance for a period.
    FINANCIAL_SITUATION                                                 = "A87"  #: A document providing the financial situation for reserves.
    CROSS_BORDER_BALANCING                                              = "A88"  #: A document providing the cross border balancing requirements for a period.
    CONTRACTED_RESERVE_PRICES                                           = "A89"  #: A document providing the price of reserves contracted for a period.
    INTERCONNECTION_NETWORK_EXPANSION                                   = "A90"  #: A document providing information on the expansion of the interconnection network.
    COUNTER_TRADE_NOTICE                                                = "A91"  #: A document providing information on counter trades for a period.
    CONGESTION_COSTS                                                    = "A92"  #: A document providing the cost of congestion for a period.
    DC_LINK_CAPACITY                                                    = "A93"  #: A document providing the DC links for a period.
    NON_EU_ALLOCATIONS                                                  = "A94"  #: A document providing allocations made to non EU member states.
    CONFIGURATION_DOCUMENT                                              = "A95"  #: A document providing configuration information.
    REDISPATCH_ACTIVATION_DOCUMENT                                      = "A96"  #: A document enabling the activation of a redispatch notice.
    DETAILED_ACTIVATION_HISTORY_DOCUMENT                                = "A97"  #: A document enabling a detailed history of activations.
    AGGREGATED_ACTIVATION_HISTORY_DOCUMENT                              = "A98"  #: A document enabling an aggregated history of activations.
    HVDC_LINK_CONSTRAINTS                                               = "A99"  #: A document providing the information concerning the maximum and minimum active power flow through each link can limited.
    HVDC_CONFIGURATION                                                  = "B01"  #: A document providing the information concerning the power set point. The mode in which the HVDC is managed.
    HVDC_SCHEDULE                                                       = "B02"  #: A document providing the information for operating DC links.
    EIC_CODE_REQUEST                                                    = "B03"  #: A document providing the information requesting a new EIC code.
    EIC_CODE_INFORMATION                                                = "B04"  #: A document providing EIC information in a central registry exchange or information to an EIC participant.
    EIC_CODE_PUBLICATION                                                = "B05"  #: A document providing EIC publication information in a web site publication of a limited set of information.
    CRITICAL_NETWORK_ELEMENT_DETERMINATION                              = "B06"  #: A document providing all the elements necessary for the capacity coordinator to determine the transfer capacity and the associated critical network elements.
    CRITICAL_NETWORK_ELEMENT_PUBLICATION                                = "B07"  #: A document providing all the elements necessary for the market information aggregator and TSOs to know the critical network elements which limit the transfer capacity.
    FLOW_BASED_DOMAIN                                                   = "B08"  #: A document providing the capacity domain and its limits available for the TSO.
    FLOW_BASED_DOMAIN_PUBLICATION                                       = "B09"  #: A document providing the capacity domain and its limits available for the market.
    FLOW_BASED_DOMAIN_MARKET_IMPACT_PUBLICATION                         = "B10"  #: A document providing the capacity domain and its impacts on the market to be published.
    ANONYMIZED_FLOW_BASED_PARAMETERS_PUBLICATION                        = "B11"  #: A document providing all the relevant flow based parameters in case of flow based capacity allocation.
    CRITICAL_NETWORK_ELEMENT_MARKET_IMPACT_PUBLICATION                  = "B12"  #: A document providing the critical network elements and its impacts on the market to be published.
    WEATHER_DOCUMENT                                                    = "B13"  #: An estimation or prediction in advance of the weather by analysis of meteorological data and the results of what actually happened with the weather.
    ENERGY_PROGNOSIS_DOCUMENT                                           = "B14"  #: A document to provide the prognosis of energy production/load for a given period.
    NETWORK_CONSTRAINT_DOCUMENT                                         = "B15"  #: A document providing the network constraint situations used for the load flow studies. A network constraint situation includes contingencies, monitored elements and remedial actions.
    AGGREGATED_NETTED_EXTERNAL_MARKET_SCHEDULE_DOCUMENT                 = "B16"  #: A document used to report aggregated netted external market schedules for a given border.
    AGGREGATED_NETTED_EXTERNAL_TSO_SCHEDULE_DOCUMENT                    = "B17"  #: A document used to report aggregated netted external TSO schedules for a given border.
    REPORTING_STATUS_MARKET_DOCUMENT                                    = "B18"  #: A document used to report the status of aggregated netted external market schedules, aggregated netted external TSO schedules and compensation program schedules on a given border.
    REPORTING_INFORMATION_MARKET_DOCUMENT                               = "B19"  #: A document used to report the information concerning aggregated netted external schedules, aggregated netted external market schedules, aggregated netted external TSO schedules, compensation program schedules, netted area position schedules and netted area AC position schedules to an interested party.
    STATUS_REQUEST_FOR_A_REPORTING_INFORMATION_MARKET_DOCUMENT          = "B20"  #: A document requesting the provision of a reporting information document.
    RESERVE_NEED_DOCUMENT                                               = "B21"  #: Used by a TSO to send its reserve needs.
    GENERATION_AND_LOAD_SHIFT_KEYS_DOCUMENT                             = "B22"  #: A document providing the values of the generation and load shift keys to be used on network model.
    OFFERS_TO_BE_ACTIVATED                                              = "B23"  #: A document containing the outcome of the process, with the list of offers that are to be activated by the TSO concerned and the results for its reserve needs.
    CLEARING_PRICE                                                      = "B24"  #: A document containing the outcome of the process, with the clearing prices for a period.
    SECURITY_ANALYSIS_REPORT                                            = "B25"  #: A document providing a report on a performed security analysis.
